@@ -9,10 +9,11 @@ console = Console()
 
 def init(subparsers: argparse._SubParsersAction):
   parser = subparsers.add_parser("log", help="show resource change history")
+  parser.add_argument("glob", nargs="?", default="*", help="select resources by glob pattern")
   parser.set_defaults(func=exec)
 
-def exec(bossman: Bossman, *args, **kwargs):
-  resources = bossman.get_resources()
+def exec(bossman: Bossman, glob, *args, **kwargs):
+  resources = bossman.get_resources(glob=glob)
   revisions = bossman.get_revisions(resources=resources)
   for revision in revisions:
     console.print(revision)
